==> igniteui-react-16.16.2.tgz: package/esm5/lib/igr-pane-close-event-args.js <==
import { PaneCloseEventArgs as PaneCloseEventArgs_internal } from "./PaneCloseEventArgs";
var IgrPaneCloseEventArgs = /** @class */ /*@__PURE__*/ (function () {
    function IgrPaneCloseEventArgs() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    IgrPaneCloseEventArgs.prototype.createImplementation = function () {
        return new PaneCloseEventArgs_internal();
    };
    Object.defineProperty(IgrPaneCloseEventArgs.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrPaneCloseEventArgs.prototype.onImplementationCreated = function () {
    };
    IgrPaneCloseEventArgs.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    };
    Object.defineProperty(IgrPaneCloseEventArgs.prototype, "detail", {
        get: function () {
            if (this.i.a == null) {
                return null;
            }
            if (!this.i.a.externalObject) {
                var e = new IgrPaneCloseEventArgs();
                e._implementation = this.i.a;
                this.i.a.externalObject = e;
            }
            return this.i.a.externalObject;
        },
        set: function (v) {
            v == null ? this.i.a = null : this.i.a = v.i;
        },
        enumerable: false,
        configurable: true
    });
    return IgrPaneCloseEventArgs;
}());
export { IgrPaneCloseEventArgs };

==> igniteui-react-18.6.0.tgz: package/esm5/lib/igr-pane-close-event-args.js <==
import { IgrPaneCloseEventArgsDetail } from "./igr-pane-close-event-args-detail";
import { PaneCloseEventArgs as PaneCloseEventArgs_internal } from "./PaneCloseEventArgs";
var IgrPaneCloseEventArgs = /** @class */ /*@__PURE__*/ (function () {
    function IgrPaneCloseEventArgs() {
        this.mounted = false;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    }
    IgrPaneCloseEventArgs.prototype.createImplementation = function () {
        return new PaneCloseEventArgs_internal();
    };
    Object.defineProperty(IgrPaneCloseEventArgs.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrPaneCloseEventArgs.prototype.onImplementationCreated = function () {
    };
    IgrPaneCloseEventArgs.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    };
    Object.defineProperty(IgrPaneCloseEventArgs.prototype, "detail", {
        get: function () {
            var r = this.i.b;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = new IgrPaneCloseEventArgsDetail();
                if (r.$type) {
                    e._implementation = r;
                }
                else {
                    if (e.i.setNativeElement) {
                        e.i.setNativeElement(r);
                    }
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            v == null ? this.i.b = null : this.i.b = v.i;
        },
        enumerable: false,
        configurable: true
    });
    return IgrPaneCloseEventArgs;
}());
export { IgrPaneCloseEventArgs };
